.. _plugin-overview:

Plugins overview
=================

.. note::

  Adding **plugins** to earthkit-data extends functionalities without the need of modifying the core package. Plugins can be distributed as standard Python packages enabling code sharing with other users and stakeholders.


The plugin mechanism is based on ``entry_points`` as described in the following page:

.. toctree::
   :maxdepth: 1

   plugins


The currently supported list of plugin types is as follows:

.. toctree::
   :maxdepth: 1

   sources_plugin
